@@ -148,6 +148,9 @@ class EartagWindow(Adw.ApplicationWindow):
             "revealed",
             GObject.BindingFlags.BIDIRECTIONAL | GObject.BindingFlags.SYNC_CREATE,
         )
+        self.sidebar_file_list.connect(
+            "notify::selection-mode", self.update_selection_mode
+        )
 
         self.connect("close-request", self.on_close_request)
 
@@ -590,6 +593,11 @@ class EartagWindow(Adw.ApplicationWindow):
         # Workaround for the text not showing up on initial load
         self.refresh_actionbar_button_state()
 
+    def update_selection_mode(self, filelist, *args):
+        self.notify("selection-mode")
+        # Workaround for the text not showing up on initial load
+        self.refresh_actionbar_button_state()
+
     def select_next(self, *args):
         """Selects the next item on the sidebar."""
         return self.file_manager.select_next()
